@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  LibreDWG - free implementation of the DWG file format                    */
 /*                                                                           */
-/*  Copyright (C) 2018 Free Software Foundation, Inc.                        */
+/*  Copyright (C) 2018-2019 Free Software Foundation, Inc.                   */
 /*                                                                           */
 /*  This library is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -22,9 +22,13 @@
 #include "bits.h"
 
 const char *dxf_format (int code);
-const char* dxf_codepage (int code, Dwg_Data* dwg);
+const char *dxf_codepage (int code, Dwg_Data *dwg);
 
-EXPORT int dwg_write_dxf(Bit_Chain *dat, Dwg_Data* dwg);
-EXPORT int dwg_write_dxfb(Bit_Chain *dat, Dwg_Data* dwg);
+int dxf_is_sorted_INSERT (const Dwg_Object *restrict obj);
+int dxf_is_sorted_POLYLINE (const Dwg_Object *restrict obj);
+int dxf_validate_DICTIONARY (Dwg_Object *obj);
+
+EXPORT int dwg_write_dxf (Bit_Chain *dat, Dwg_Data *dwg);
+EXPORT int dwg_write_dxfb (Bit_Chain *dat, Dwg_Data *dwg);
 
 #endif
